@@ -1,4 +1,12 @@
 #!/usr/bin/env python
+#
+# This file is part of the cpthook library.
+#
+# cpthook is free software released under the BSD License.
+# Please see the LICENSE file included in this distribution for
+# terms of use. This LICENSE is also available at
+# https://github.com/aelse/cpthook/blob/master/LICENSE
+
 
 import logging
 import os
@@ -290,21 +298,20 @@ class CptHookConfig(object):
 
 
 class CptHook(object):
-    """A git hook execution layer
-
-    CptHook provides a mechanism for running multiple hook scripts
-    for a particular hook type (eg. post-commit) for configured
-    repositories.
-
-    This class manages repository hooks, installing a wrapper that
-    executes the cpthook program to run each of the hook scripts
-    configured to be run for a hook type in a repository.
-
-    Configuration is managed through an ini-style file
-    (see CptHookConfig)"""
 
     def __init__(self, config_file):
-        """Called with the filename of a cpthook configuration file"""
+        """A git hook execution layer
+
+        CptHook provides a mechanism for running multiple hook scripts
+        for a particular hook type (eg. post-commit) for configured
+        repositories.
+
+        This class manages repository hooks, installing a wrapper that
+        executes the cpthook program to run each of the hook scripts
+        configured to be run for a hook type in a repository.
+
+        Configuration is managed through an ini-style file
+        (see CptHookConfig)"""
         self.config_file = config_file
         self.config = CptHookConfig(config_file)
         self.dry_run = False
